<?php
session_start();

include('database.php');

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

$stmt = $conn->prepare("SELECT first_name, last_name, email, phone, account_type FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id); 
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $first_name = $user['first_name'];
    $last_name = $user['last_name'];
    $email = $user['email'];
    $phone = $user['phone'];
    $account_type = $user['account_type'];

    if ($account_type !== 'admin') {
        header("Location: login.php");
        exit();
    }

} else {
    header("Location: login.php");
    exit();
}

// Fetch customers' data
$query = "SELECT id, first_name, last_name, email, phone FROM users WHERE account_type = 'customer'";
$result = $conn->query($query);

$customers = [];
while ($row = $result->fetch_assoc()) {
    $customers[] = [
        'id' => $row['id'],
        'name' => $row['first_name'] . ' ' . $row['last_name'],
        'email' => $row['email'],
        'phone' => $row['phone']
    ];
}

// Close connections
$stmt->close();
$conn->close();
?>


<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <meta name="keywords" content="boot, Bootstrap, Forex and Stock Broker HTML Template" />
  <meta name="description" content="Forex and Stock Broker HTML Template" />
  <title>Admin - Customers</title>
  <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
  <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
  <link rel="stylesheet" href="assets/css/style.min.css" />
</head>

<body>
  <div class="preloader">
    <span class="loader"></span>
  </div>

  <button class="scrollToTop d-none d-md-flex d-center rounded" aria-label="scroll Bar Button">
    <i class="mat-icon fs-four nb4-color ti ti-arrow-up"></i>
  </button>

  <div class="two-column_logo d-none gap-3">
    <a href="dashboard.php">
      <img src="assets/images/text_logo.png" class="logo_light" alt="Logo " />
      <img src="assets/images/text_logo_dark.png" class="logo_dark" alt="Logo" />
    </a>
    <span class="material-symbols-outlined close_nav p-1 d-xl-none">
      close
    </span>
  </div>

  <div class="manu-wrapper">
    <header class="top-menu">
      <nav
        class="top-menu__content py-5 py-xxl-8 px-3 px-lg-4 px-xxl-6 d-flex align-items-center justify-content-between gap-6">
      </nav>
    </header>

    <div class="company-logo d-center justify-content-between gap-2">
      <a href="dashboard.php" class="logo_area">
        <span class="logo-xl">
          <img src="assets/images/logo_light.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_light.png" class="short_logo" alt="Logo" />
        </span>
        <span class="logo-xl logo_dark">
          <img src="assets/images/logo_dark.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_dark.png" class="short_logo" alt="Logo" />
        </span>
      </a>
      <span class="material-symbols-outlined close_nav p-1 d-xl-none">
        close
      </span>
    </div>

    <aside class="aside-wrapper">
      <div class="main-menu">
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold">Admin Panel</li>
          <li class="nav_item">
            <a href="admin_customers.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                house
              </span>
              <span class="nav_text">Customers</span>
            </a>
            <a href="admin_customers_transactions.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                money
              </span>
              <span class="nav_text">Transactions</span>
            </a>
          </li>
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold"></li>
          <li>
            <a href="logout.html" class="nav_link">
              <span class="material-symbols-outlined p1-color fs-four-up">
                logout
              </span>
              <span href="log_out.html" class="nav_text">Log out</span>
            </a>
          </li>
        </ul>

        <ul class="main-menu__part logout_area mt-auto d-none">
          <li>
            <a href="logout.html"><span class="material-symbols-outlined p1-color">
                logout
              </span></a>
          </li>
        </ul>

      </div>
    </aside>
  </div>


<div class="main-content overflow-hidden">
    <div class="container-fluid">
      <div class="col-12">
        <div class="table-area overview_list n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
          <div class="header-part d-flex justify-content-between align-items-center gap-8 pb-5">
            <h4 class="fw-semibold">Customers</h4>
            <input type="text" id="searchInput" class="form-control" placeholder="Search Customers" onkeyup="searchCustomers()">
          </div>
          <div class="table-main">
            <table id="customerTable">
              <thead>
                <tr>
                  <th>Customer Name</th>
                  <th>Customer Email</th>
                  <th>Phone Number</th>
                  <th>Edit</th>
                </tr>
              </thead>
              <tbody>
                <?php
                foreach ($customers as $customer) {
                  echo "<tr>
                    <td><span class='fw-medium'>{$customer['name']}</span></td>
                    <td><span class='fw-medium'>{$customer['email']}</span></td>
                    <td><span class='fw-medium'>{$customer['phone']}</span></td>
                    <td>
                      <button onclick=\"editCustomer({$customer['id']})\" 
                        class='btn_box btn_alt cus-border border-color py-2 px-4'>
                        Edit
                      </button>
                    </td>
                  </tr>";
                }
                ?>
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>
  </div>


<script>
function searchCustomers() {
  let input = document.getElementById('searchInput').value.toLowerCase();
  let rows = document.querySelectorAll('#customerTable tbody tr');

  rows.forEach(row => {
    let name = row.querySelector('td:nth-child(1)').textContent.toLowerCase();
    let email = row.querySelector('td:nth-child(2)').textContent.toLowerCase();
    let phone = row.querySelector('td:nth-child(3)').textContent.toLowerCase();

    if (name.includes(input) || email.includes(input) || phone.includes(input)) {
      row.style.display = '';
    } else {
      row.style.display = 'none';
    }
  });
}
</script>

<script>
  function editCustomer(customerId) {
    window.location.href = `edit_customer.php?id=${customerId}`;
  }
</script>

<script src="assets/js/plugins/plugins.js"></script>
<script src="assets/js/plugins/apexcharts.min.js"></script>
<script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
<script src="assets/js/plugins/custom_apexcharts.js"></script>
<script src="assets/js/plugins/plugin-custom.js"></script>
<script src="assets/js/main.js"></script>

</body>

</html>
