<?php
session_start();

include('database.php');

if (!isset($_SESSION['user_id'])) {
    // If the user is not logged in, redirect to login page
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id); 
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $first_name = $user['first_name'];
    $last_name = $user['last_name'];
    $email = $user['email'];
    $phone = $user['phone'];
    $account_type = $user['account_type'];
    $btc_balance = $user['btc_balance'];
    $eth_balance = $user['eth_balance'];
    $trx_balance = $user['trx_balance'];
    $usdt_balance = $user['usdt_balance'];
    $country = $user['country'];
    $address1 = $user['address1'];
    $address2 = $user['address2'];
    $zip_code = $user['zip_code'];
    $id_verification_status = $user['id_verification_status'];
    $bank_verification_status = $user['bank_verification_status'];
    $created_at = $user['created_at'];
} else {
    header("Location: login.php");
    exit();
}

$transactionQuery = $conn->prepare("SELECT * FROM transactions WHERE user_id = ? ORDER BY date_time DESC LIMIT 10");
$transactionQuery->bind_param("i", $user_id);
$transactionQuery->execute();
$transactionResult = $transactionQuery->get_result();

$transactions = [];
while ($transaction = $transactionResult->fetch_assoc()) {
    $transactions[] = $transaction;  
}

// var_dump('transactions', $transactions);

$wallet = [
    'btc_balance' => $btc_balance ?? 0,
    'eth_balance' => $eth_balance ?? 0,
    'trx_balance' => $trx_balance ?? 0,
    'usdt_balance' => $usdt_balance ?? 0
];

$stmt->close();
$transactionQuery->close();
$conn->close();
?>


<!DOCTYPE html>
<html lang="en">

<head>
  <!-- required meta -->
  <meta charset="UTF-8" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <!-- #keywords -->
  <meta name="keywords" content="Crypto Portfolio - Dashboard" />
  <!-- #description -->
  <meta name="description" content="Crypto Portfolio - Dashboard" />
  <!-- #title -->
  <title>Crypto - Dashboard</title>
  <!-- #favicon -->
  <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
  <!-- ==== css dependencies start ==== -->
  <link href="//cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
  <link rel="stylesheet" href="assets/css/style.min.css" />
</head>

<body class="vertical">
  <!--  Preloader  -->
  <div class="preloader">
    <span class="loader"></span>
  </div>
  <!-- end preloader -->

  <!-- Scroll To Top Start-->
  <button class="scrollToTop d-none d-md-flex d-center rounded" aria-label="scroll Bar Button">
    <i class="mat-icon fs-four nb4-color ti ti-arrow-up"></i>
  </button>
  <!-- Scroll To Top End -->

  <!-- header-section start -->

  <div class="two-column_logo d-none gap-3">
    <a href="dashboard.php">
      <img src="assets/images/text_logo.png" class="logo_light" alt="Logo " />
      <img src="assets/images/text_logo_dark.png" class="logo_dark" alt="Logo" />
    </a>
    <span class="material-symbols-outlined close_nav p-1 d-xl-none">
      close
    </span>
  </div>

  <div class="manu-wrapper">
    <!--header-section start-->
    <header class="top-menu">
      <nav
        class="top-menu__content py-5 py-xxl-8 px-3 px-lg-4 px-xxl-6 d-flex align-items-center justify-content-between gap-6">
        <div class="top-menu__left d-flex gap-3 gap-xxl-6">
          <button class="nav_tab d-center cus-rounded-2 left d-none d-md-flex">
            <span class="material-symbols-outlined fs-two n700-color">
              menu
            </span>
          </button>
          <button class="nav_tab second p1-bg d-center cus-rounded-2 left">
            <span class="navbar-toggle-btn box_15 overflow-hidden cus-border-dashed rounded-circle d-md-none">
              <span></span>
              <span></span>
              <span></span>
              <span></span>
            </span>
          </button>
          <div class="company-short-logo d-center justify-content-between gap-2 d-xl-none">
            <a href="dashboard.php" class="logo_area">
              <span class="logo-xl">
                <img src="assets/images/short_logo_light.png" class="logo" alt="Logo" />
              </span>
              <span class="logo-xl logo_dark">
                <img src="assets/images/short_logo_dark.png" class="logo" alt="Logo" />
              </span>
            </a>
          </div>
          <div class="d-flex align-items-center gap-3">
            <form method="POST" class="search__form_nav d-none d-md-flex">

            </form>
          </div>
        </div>
        <div class="top-menu__right d-flex gap-1 gap-md-3 gap-xxl-6 z-0 align-items-center">
          <div class="btn_box btn_alt box_12 cus-border nav_search_short d-md-none">
            <span class="material-symbols-outlined fs-four"> search </span>
          </div>
          <div class="toggle-switch btn_box btn_alt box_12 cus-border">
            <input type="checkbox" class="checkbox" id="checkbox" />
            <label for="checkbox" class="checkbox-label">
              <span class="material-symbols-outlined fs-four">
                dark_mode
              </span>
              <span class="material-symbols-outlined fs-four light_mode">
                light_mode
              </span>
            </label>
          </div>
          <div class="position-relative notification_area">
            <div class="notification_icon btn_box btn_alt box_12 cus-border d-center">
              <span class="material-symbols-outlined fs-four">
                notifications
              </span>
            </div>
            <ul class="notification_nav hover-scroll d-flex flex-column gap-4 n0-bg px-4 px-lg-5 py-4 cus-rounded-1">
              <li>
                <div class="d-flex align-items-center gap-3">
                  <a href="#" class="user_profile_thumb">
                    <img src="assets/images/user_profile10.png" class="rounded-circle" alt="image" />
                  </a>
                  <div class="user_profile_title flex-fill">
                    <a href="#">Theresa Webb</a>
                    <p class="mt-1 fs-eight">just ideas for next time</p>
                  </div>
                  <div class="notification just_active d-center flex-column">
                    <span class="notification__count box_6 rounded-circle d-center fs-eight">5</span>
                    <span class="notification__time fs-eight">4m</span>
                  </div>
                </div>
              </li>
              <li>
                <div class="d-flex align-items-center gap-3">
                  <a href="#" class="user_profile_thumb">
                    <img src="assets/images/user_profile9.png" class="rounded-circle" alt="image" />
                  </a>
                  <div class="user_profile_title flex-fill">
                    <a href="#">Bessie Cooper</a>
                    <p class="mt-1 fs-eight">omg, this is amazing</p>
                  </div>
                  <div class="notification just_active d-center flex-column">
                    <span class="notification__count box_6 rounded-circle d-center fs-eight">1</span>
                    <span class="notification__time fs-eight">5m</span>
                  </div>
                </div>
              </li>
            </ul>
          </div>

          <div class="lang_nav box_12 position-relative cus-border rounded-3">
            <div onclick="toggleDropNav()" class="nav_dropdown_btn btn_box btn_alt box_12 d-center bg1-opty">
              <img src="assets/images/unitedkingdom.png" alt="United Kingdom" class="flag-img rounded-circle box_6" />
              <span class="nav_lang d-none">United Kingdom</span>
            </div>
            <ul class="lang_nav_list hover-scroll position-absolute py-1 py-lg-2 n0-bg cus-rounded-1">
              <li onclick="selectOptionNav('United Kingdom', 'assets/images/united-kingdom.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/unitedkingdom.png" alt="United Kingdom" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">United Kingdom</span>
              </li>
              <li onclick="selectOptionNav('Canada', 'assets/images/canada.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/canada.png" alt="Canada" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">Canada</span>
              </li>
              <li onclick="selectOptionNav('Australia', 'assets/images/australia.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/australia.png" alt="Australia" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">Australia</span>
              </li>
              <li onclick="selectOptionNav('France', 'assets/images/france.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/france.png" alt="France" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">France</span>
              </li>
            </ul>
          </div>


          <div class="user-account box_12 position-relative">
            <div class="profile-nav">
              <img src="assets/images/user.png" class="box_12 cus-rounded-1" alt="img" />
            </div>
            <ul class="user-profile hover-scroll n0-bg d-flex flex-column gap-1 p-3 cus-rounded-1">
              <li>
                <a href="settings.php" class="d-flex align-items-center gap-2 p1-color"><span
                    class="material-symbols-outlined fs-four">
                    person </span>My Account</a>
              </li>
              <li>
                <a href="log_out.html class=" d-flex align-items-center gap-2 p1-color"><span
                    class="material-symbols-outlined fs-four">
                    logout </span>Log Out</a>
              </li>
            </ul>
          </div>
        </div>
      </nav>
    </header>

    <!-- aside start -->
    <div class="company-logo d-center justify-content-between gap-2">
      <a href="dashboard.php" class="logo_area">
        <span class="logo-xl">
          <img src="assets/images/logo_light.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_light.png" class="short_logo" alt="Logo" />
        </span>
        <span class="logo-xl logo_dark">
          <img src="assets/images/logo_dark.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_dark.png" class="short_logo" alt="Logo" />
        </span>
      </a>
      <span class="material-symbols-outlined close_nav p-1 d-xl-none">
        close
      </span>
    </div>

    <aside class="aside-wrapper">
      <div class="main-menu">
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold">Dashboard</li>
          <li class="nav_item">
            <a href="dashboard.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                house
              </span>
              <span class="nav_text">Dashboard</span>
            </a>
          </li>
          <li class="nav_item">
            <a href="wallet.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                layers
              </span>
              <span class="nav_text">Wallets</span>
            </a>
          </li>
          <li class="nav_dropdown">
            <button class="dropdown_arrow">
              <span class="material-symbols-outlined fs-four-up">
                account_circle
              </span>
              <span class="nav_text">Account</span>
            </button>
            <ul class="nav_dropdown-menu">
              <li><a href="settings.php">Settings</a></li>
              <li><a href="password.php">Password</a></li>
            </ul>
          </li>
          <li class="nav_item">
            <a href="contact.html" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                phone
              </span>
              <span class="nav_text">Contact Us</span>
            </a>
          </li>
        </ul>
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold"></li>
          <li>
            <a href="logout.html" class="nav_link">
              <span class="material-symbols-outlined p1-color fs-four-up">
                logout
              </span>
              <span href="log_out.html" class="nav_text">Log out</span>
            </a>
          </li>
        </ul>

        <ul class="main-menu__part logout_area mt-auto d-none">
          <li>
            <a href="logout.html"><span class="material-symbols-outlined p1-color">
                logout
              </span></a>
          </li>
        </ul>

      </div>
    </aside>

    <!-- aside end -->
  </div>
  <div class="clone_area d-center"></div>
  <!-- header-section end -->

  <!-- main-body start -->
  <div class="main-content">
    <div class="container-fluid">
      <div class="row">
        <div class="col-12">
          <div class="top-area flex-wrap d-center justify-content-between gap-8 row-gap-3">
            <h2>Crypto Holdings</h2>
            <div class="d-flex align-items-center gap-3 gap-lg-6">
              <button type="submit"
                class="btn_box cus-border border-color py-2 py-lg-3 py-xxl-4 px-4 px-lg-5 px-xxl-8 gap-2 gap-lg-3"
                data-bs-toggle="modal" data-bs-target="#withrawcrypto">
                <span class="material-symbols-outlined">add_circle </span>
                Withraw Crypto
              </button>
            </div>
          </div>
        </div>
      </div>

      <div class="row g-4 g-md-6 four_grid">
        <!-- BTC -->
        <!-- BTC -->
    <div class="col-sm-6 col-xxl-3">
        <div class="n0-bg cus-rounded-1 p-4 p-lg-6 p-xxl-8 cus-border h-100 cursor-pointer" onclick="showChart('BTC')">
            <div class="header-part pb-4 mb-4">
                <h4 class="d-flex align-items-center gap-3">
                    <img src="assets/images/bitcoin_mid.png" class="box_8" alt="Icon" />BTC
                </h4>
            </div>
            <div class="d-flex align-items-center justify-content-between gap-1 gap-sm-2 gap-lg-4">
                <div class="text-nowrap">
                    <h4 class="n700-color">
                        <?php echo number_format($wallet['btc_balance'], 8); ?>
                    </h4>
                    <p class="s1-color d-flex align-items-center gap-1 mt-3">
                        <span class="material-symbols-outlined"> show_chart </span>
                        <span class="btc-value">---$$---</span> <!-- Placeholder for USD value -->
                    </p>
                </div>
                <div class="fin_area_short"></div>
            </div>
        </div>
    </div>

    <!-- ETH -->
    <div class="col-sm-6 col-xxl-3">
        <div class="n0-bg cus-rounded-1 p-4 p-lg-6 p-xxl-8 cus-border h-100 cursor-pointer" onclick="showChart('ETH')">
            <div class="header-part pb-4 mb-4">
                <h4 class="d-flex align-items-center gap-3">
                    <img src="assets/images/ethereum_mid.png" class="box_8" alt="Icon" />ETH
                </h4>
            </div>
            <div class="d-flex align-items-center justify-content-between gap-1 gap-sm-2 gap-lg-4">
                <div class="text-nowrap">
                    <h4 class="n700-color">
                        <?php echo number_format($wallet['eth_balance'], 8); ?>
                    </h4>
                    <p class="p1-color d-flex align-items-center gap-1 mt-3">
                        <span class="material-symbols-outlined"> show_chart </span>
                        <span class="eth-value">---$$---</span> <!-- Placeholder for USD value -->
                    </p>
                </div>
                <div class="fin_area_short"></div>
            </div>
        </div>
    </div>

    <!-- TRX -->
    <div class="col-sm-6 col-xxl-3">
        <div class="n0-bg cus-rounded-1 p-4 p-lg-6 p-xxl-8 cus-border h-100 cursor-pointer" onclick="showChart('TRX')">
            <div class="header-part pb-4 mb-4">
                <h4 class="d-flex align-items-center gap-3">
                    <img src="assets/images/tron_med.png" class="box_8" alt="Icon" />TRX
                </h4>
            </div>
            <div class="d-flex align-items-center justify-content-between gap-1 gap-sm-2 gap-lg-4">
                <div class="text-nowrap">
                    <h4 class="n700-color">
                        <?php echo number_format($wallet['trx_balance'], 8); ?>
                    </h4>
                    <p class="s2-color d-flex align-items-center gap-1 mt-3">
                        <span class="material-symbols-outlined"> show_chart </span>
                        <span class="trx-value">---$$---</span> <!-- Placeholder for USD value -->
                    </p>
                </div>
                <div class="fin_area_short"></div>
            </div>
        </div>
    </div>

    <!-- USDT -->
    <div class="col-sm-6 col-xxl-3">
        <div class="n0-bg cus-rounded-1 p-4 p-lg-6 p-xxl-8 cus-border h-100 cursor-pointer" onclick="showChart('USDT')">
            <div class="header-part pb-4 mb-4">
                <h4 class="d-flex align-items-center gap-3">
                    <img src="assets/images/tether_mid.png" class="box_8" alt="Icon" />USDT
                </h4>
            </div>
            <div class="d-flex align-items-center justify-content-between gap-1 gap-sm-2 gap-lg-4">
                <div class="text-nowrap">
                    <h4 class="n700-color">
                        <?php echo number_format($wallet['usdt_balance'], 8); ?>
                    </h4>
                    <p class="s1-color d-flex align-items-center gap-1 mt-3">
                        <span class="material-symbols-outlined"> show_chart </span>
                        <span class="usdt-value">---$$---</span> <!-- Placeholder for USD value -->
                    </p>
                </div>
                <div class="fin_area_short"></div>
            </div>
        </div>
    </div>
</div>

      <div class="row g-6">
        <div class="col-xxl-9">
          <div class="d-flex flex-column gap-6 h-100">
            <div class="n0-bg cus-rounded-1 p-4 p-lg-6 cus-border">
              <div
                class="header-part d-flex flex-wrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-2">
                <h4 class="fw-semibold" id="assetName">BTC</h4>
                <div class="d-flex flex-wrap flex-sm-nowrap gap-4 gap-xxl-6">
                  <div class="cus_select d-flex align-items-center gap-2">
                  </div>
                </div>
              </div>
              <div class="fin_total_area" id="fin_total_area"></div>
            </div>


            <div class="table-area n0-bg cus-rounded-1 p-4 p-lg-6 cus-border">
              <div
                class="header-part d-flex flex-wrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
                <h4 class="fw-semibold">Transaction History</h4>
                <div class="d-flex flex-wrap flex-sm-nowrap gap-4 gap-xxl-6">
                </div>
              </div>
              <div class="table-main">
    <table>
      <tr>
        <th>Title</th>
        <th>Date</th>
        <th>Type of Transfer</th>
        <th>Status</th>
        <th>Transaction</th>
        <th>Value</th> <!-- New Value Column -->
      </tr>
      <?php
// API URL for CoinCap
$apiUrl = 'https://api.coincap.io/v2/assets';

// Fetch data from CoinCap API
$response = file_get_contents($apiUrl);
$data = json_decode($response, true);
$assetPrices = [];
foreach ($data['data'] as $asset) {
    $assetPrices[$asset['symbol']] = $asset['priceUsd'];
}

// Loop through the transactions and display them
foreach ($transactions as $transaction) {
    // Set the asset image and name based on the 'asset' field
    $asset_image = '';
    switch ($transaction['asset']) {
        case 'BTC':
            $asset_image = 'bitcoin.png';
            break;
        case 'ETH':
            $asset_image = 'ethereum.png';
            break;
        case 'TRX':
            $asset_image = 'tron_min.png';
            break;
        case 'USDT':
            $asset_image = 'tether.png';
            break;
        default:
            $asset_image = 'bitcoin.png'; // Default to BTC if asset type is unknown
            break;
    }

    // Set status colors based on the transaction status
    $status_class = '';
    $status_text = '';
    switch ($transaction['status']) {
        case 'Successful':
            $status_class = 'bg2-opty s1-color'; // Green for successful
            $status_text = 'Successful';
            break;
        case 'Pending':
            $status_class = 'bg4-opty s3-color'; // Yellow for pending
            $status_text = 'Pending';
            break;
        case 'Rejected':
            $status_class = 'bg3-opty s2-color'; // Red for rejected
            $status_text = 'Rejected';
            break;
        default:
            $status_class = 'bg2-opty s1-color'; // Default to successful
            $status_text = 'Unknown';
            break;
    }

    // Format the date
    $transaction_date = date('m/d/Y', strtotime($transaction['date_time']));

    // Calculate the USD value for the transaction
    $assetValueInUsd = $transaction['amount'] * $assetPrices[$transaction['asset']];
    $formattedUsdValue = number_format($assetValueInUsd, 2);

    // Determine if the transaction is a withdrawal or deposit for styling purposes
    $is_withdrawal = ($transaction['transaction_type'] == 'Withdrawal');
    
    // Adjust sign and color based on the type of transaction
    $value_class = $is_withdrawal ? 'text-danger' : 'text-success';  // Red for withdrawal, Green for deposit
    $sign = $is_withdrawal ? '-' : '';  // Add '-' for withdrawal transactions

    // Display each transaction in a table row
    echo "
    <tr>
        <td>
            <div class='d-flex align-items-center gap-3'>
                <img src='assets/images/$asset_image' alt='icon' />
                <span class='fw-medium'>" . $transaction['asset'] . "</span>
            </div>
        </td>
        <td>$transaction_date</td>
        <td>" . $transaction['transaction_type'] . "</td>
        <td>
            <span class='$status_class cus-border py-2 px-4 px-lg-5 text-center cus-rounded-2 w-100 cursor-pointer' onclick='openStatusModal(". $transaction['id'] .")'>$status_text</span>
        </td>
        <td>
            <div class='d-flex flex-column gap-1'>
                <span class='fw-medium $value_class'>$sign" . number_format($transaction['amount'], 8) . " " . $transaction['asset'] . "</span>
            </div>
        </td>
        <td>
            <div class='d-flex flex-column gap-1'>
                <span class='fw-medium'>$" . $formattedUsdValue . " USD</span> <!-- Value in USD -->
            </div>
        </td>
    </tr>";
}
?>

    </table>
  </div>
             
            </div>
          </div>
        </div>


        <div class="col-xxl-3">
          <div class="d-flex flex-column gap-6 h-100">

           <!-- Total Balance start -->
<div class="n0-bg cus-rounded-1 p-4 p-lg-6 p-xxl-8 cus-border">
  <div class="d-center justify-content-between">
    <span class="fw-medium">Balance</span>
  </div>
  <h3 class="n700-color mt-4 mb-8 mb-lg-10 total-balance">$---$---$---</h3>
  <!-- Placeholder for total balance -->
  <div class="d-center justify-content-between gap-6 flex-wrap">
    <div class="d-flex flex-column gap-4">
      <p class="d-flex align-items-center gap-1">
        <span class="material-symbols-outlined fs-five p1-color">
          arrow_downward
        </span>Deposits
      </p>
      <span class="fw-semibold text-success">
        <?php
        $totalDeposits = 0; // Initialize total deposits
        // Loop through the transactions and sum up deposits
        foreach ($transactions as $transaction) {
            if ($transaction['transaction_type'] == 'Deposit') {
                $totalDeposits += $transaction['amount'] * $assetPrices[$transaction['asset']];
            }
        }
        echo '+' . number_format($totalDeposits, 2) . ' USD'; // Display total deposits
        ?>
      </span> <!-- Green and positive value for Deposits -->
    </div>
    <div class="d-flex flex-column gap-4">
      <p class="d-flex align-items-center gap-1">
        <span class="material-symbols-outlined fs-five s2-color">
          arrow_upward
        </span>Withdrawals
      </p>
      <span class="fw-semibold text-danger">
        <?php
        $totalWithdrawals = 0; // Initialize total withdrawals
        // Loop through the transactions and sum up successful or pending withdrawals
        foreach ($transactions as $transaction) {
            if ($transaction['transaction_type'] == 'Withdrawal' && in_array($transaction['status'], ['Successful', 'Pending'])) {
                $totalWithdrawals += $transaction['amount'] * $assetPrices[$transaction['asset']];
            }
        }
        echo '-' . number_format($totalWithdrawals, 2) . ' USD'; // Display total withdrawals
        ?>
      </span> <!-- Red and negative value for Withdrawals -->
    </div>
  </div>
</div>

            <!-- Total Balance end -->

            <!-- Asset Allocation Start -->
            <div class="n0-bg cus-rounded-1 p-4 p-lg-6 p-xxl-8 cus-border">
              <div
                class="header-part d-flex flex-wrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
                <h4 class="fw-semibold">Asset Allocation</h4>
                <span class="material-symbols-outlined fs-four n500-color">
                  refresh
                </span>
              </div>
              <div class="d-flex flex-column gap-5 gap-lg-6">
                <div class="separator_line_dashed d-flex gap-3 gap-lg-5 pb-5 pb-lg-6">
                  <div class="icon">
                    <img src="assets/images/bitcoin_lg.png" alt="image" />
                  </div>
                  <div class="d-flex flex-column gap-2 w-100">
                    <div class="d-flex justify-content-between">
                      <span class="fw-medium fs-five"> BTC</span>
                      <span class="fs-five">95</span>
                    </div>
                    <div class="progress_area d-flex gap-3 align-items-center">
                      <span class="cssProgress-label" id="btcPercent">0%</span>
                      <div class="cssProgress">
                        <div class="cssProgress-bar" id="btcPercentProgress" data-percent="0"></div>
                      </div>
                    </div>
                  </div>
                </div>
                <div class="separator_line_dashed d-flex gap-3 gap-lg-5 pb-5 pb-lg-6">
                  <div class="icon">
                    <img src="assets/images/ethereum_l.png" alt="image" />
                  </div>
                  <div class="d-flex flex-column gap-2 w-100">
                    <div class="d-flex justify-content-between">
                      <span class="fw-medium fs-five"> ETH</span>
                      <span class="fs-five">56 </span>
                    </div>
                    <div class="progress_area d-flex gap-3 align-items-center">
                      <span class="cssProgress-label" id="ethPercent">0%</span>
                      <div class="cssProgress">
                        <div class="cssProgress-bar" id="ethPercentProgress" data-percent="0"></div>
                      </div>
                    </div>
                  </div>
                </div>
                <div class="separator_line_dashed d-flex gap-3 gap-lg-5 pb-5 pb-lg-6">
                  <div class="icon">
                    <img src="assets/images/tron_min.png" alt="image" />
                  </div>
                  <div class="d-flex flex-column gap-2 w-100">
                    <div class="d-flex justify-content-between">
                      <span class="fw-medium fs-five"> TRX</span>
                      <span class="fs-five">44 </span>
                    </div>
                    <div class="progress_area d-flex gap-3 align-items-center">
                      <span class="cssProgress-label" id="trxPercent">0%</span>
                      <div class="cssProgress">
                        <div class="cssProgress-bar" id="trxPercentProgress" data-percent="0"></div>
                      </div>
                    </div>
                  </div>
                </div>
                <div class="separator_line_dashed d-flex gap-3 gap-lg-5">
                  <div class="icon">
                    <img src="assets/images/tether_l.png" alt="image" />
                  </div>
                  <div class="d-flex flex-column gap-2 w-100">
                    <div class="d-flex justify-content-between">
                      <span class="fw-medium fs-five"> USDT</span>
                      <span class="fs-five">32 </span>
                    </div>
                    <div class="progress_area d-flex gap-3 align-items-center">
                      <span class="cssProgress-label" id="usdtPercent">0%</span>
                      <div class="cssProgress">
                        <div class="cssProgress-bar" id="usdtPercentProgress" data-percent="0"></div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
            <!-- Asset Allocation End -->
          </div>
        </div>
      </div>
    </div>
  </div>
  <!-- main end -->

  <!-- Modal -->

  <!-- Withdraw Crypto start -->
<div class="modal calendar-modal fade" id="withrawcrypto" data-bs-backdrop="static" data-bs-keyboard="false"
  tabindex="-1" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content n0-bg p-4 p-md-6 p-xxl-8">
      <div class="modal-header header-part mb-5 mb-lg-6 pb-5 pb-lg-6">
        <h4 class="modal-title">Withdraw Crypto</h4>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" id="withdrawClose"></button>
        <button type="button" class="btn-close d-none" data-bs-dismiss="modal" aria-label="Close" id="withdrawCloseSuccess"></button>
      </div>
      <div class="modal-body">
        <form method="post" class="d-flex flex-column gap-5 gap-lg-6" id="withdrawForm">
         <input type="hidden" name="user_id" id="userId" value="<?php echo $user_id; ?>">
          <div
            class="position-relative d-center flex-column gap-4 cus-border-dashed bottom border-color-30 pb-5 pb-lg-6">

            <!-- From Area -->
            <div class="from_area bg1-opty cus-rounded-1 cus-border p-4 p-md-6 p-xxl-8 w-100">
              <div class="d-flex justify-content-between cus-border-dashed bottom pb-4 mb-4">
                <span>From</span>
                <span class="balance-text">Balance: 0.00 <span id="selectedFromCurrencyLabel">BTC</span></span> <!-- Dynamically updated balance -->
              </div>
              <div class="input_area d-center justify-content-between gap-3">
                <input type="text" name="from" id="withdrawAmount" class="alt_input fw-medium fs-five" placeholder="0.00" required />
                <div class="dropdown d-center gap-3">
                  <!-- Dropdown button with transparent background -->
                  <button class="btn btn-transparent dropdown-toggle" type="button" id="cryptoDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                    <img src="assets/images/bitcoin_mid.png" class="box_7" alt="BTC" />
                    <span class="fw-medium fs-five" id="selectedFromCurrency">BTC</span>
                  </button>
                  <!-- Dropdown menu with black border -->
                  <ul class="dropdown-menu custom-dropdown-menu" aria-labelledby="cryptoDropdown">
                    <li>
                      <a class="dropdown-item" href="#" data-currency="BTC" data-img="bitcoin_mid.png">
                        <img src="assets/images/bitcoin_mid.png" class="box_7" alt="BTC" />
                        <span class="fw-medium fs-five">BTC</span>
                      </a>
                    </li>
                    <li>
                      <a class="dropdown-item" href="#" data-currency="ETH" data-img="ethereum_mid.png">
                        <img src="assets/images/ethereum_mid.png" class="box_7" alt="ETH" />
                        <span class="fw-medium fs-five">ETH</span>
                      </a>
                    </li>
                    <li>
                      <a class="dropdown-item" href="#" data-currency="TRX" data-img="tron_med.png">
                        <img src="assets/images/tron_med.png" class="box_7" alt="TRX" />
                        <span class="fw-medium fs-five">TRX</span>
                      </a>
                    </li>
                    <li>
                      <a class="dropdown-item" href="#" data-currency="USDT" data-img="tether_mid.png">
                        <img src="assets/images/tether_mid.png" class="box_7" alt="USDT" />
                        <span class="fw-medium fs-five">USDT</span>
                      </a>
                    </li>
                  </ul>
                </div>
              </div>
            </div>

            <!-- To Area -->
            <div class="to_area bg1-opty cus-rounded-1 cus-border p-4 p-md-6 p-xxl-8 w-100">
              <div class="d-flex justify-content-between cus-border-dashed bottom pb-4 mb-4">
                <span>To</span>
                <span>Personal Wallet </span></span>
              </div>
              <div class="input_area d-center justify-content-between gap-3">
                <input type="text" name="from" id="withdrawAddress" class="alt_input fw-medium fs-five" placeholder="Wallet Address"
                  required />
                <div class="d-center gap-3">
                  <img id="selectedToCurrencyLogo" src="assets/images/bitcoin_mid.png" class="box_7" alt="BTC" />
                  <span class="fw-medium fs-five" id="selectedToCurrencyLabel">BTC</span>
                </div>
              </div>
            </div>
          </div>
          <button type="button" id="withdrawCryptoBtn"
            class="btn_box w-100 mt-2 py-2 py-lg-3 px-5 px-lg-6 cus-rounded-1 cus-border border-color">
            Withdraw Crypto
          </button>
        </form>

        <!-- Message for Order Processing -->
        <div id="orderProcessingMessage" class="d-none text-center mt-4">
          <h5>Your order is processing. Please check the status in your transaction history.</h5>
        </div>
      </div>
    </div>
  </div>
</div>
<!-- Withdraw Crypto end -->




  <!-- Add this CSS -->
  <style>
    .btn-transparent {
      background-color: transparent !important;
      border: none;
      color: inherit;
      /* Retain text color */
    }

    /* Style the dropdown menu with a black border */
    .custom-dropdown-menu {
      background-color: #fff !important;
      /* Make dropdown background white */
      border: 1px solid black !important;
      border-radius: 0.25rem;
      /* Optional: add rounded borders */
    }

    /* Dropdown item styles */
    .dropdown-item {
      background-color: transparent !important;
      color: #000 !important;
      padding: 10px;
      /* Optional: adjust padding */
    }

    .dropdown-item:hover {
      background-color: #f8f9fa !important;
      /* Optional: hover effect */
    }

    /* Additional styles for the "order processing" message */
    #orderProcessingMessage {
      font-size: 1.2rem;
      color: #007bff;
    }
  </style>



  <!-- Select Token Start -->
  <div class="modal calendar-modal fade" id="token" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
    aria-hidden="true">
    <div class="modal-dialog">
      <div class="modal-content n0-bg py-4 py-sm-6 py-lg-8 px-2 px-lg-4">
        <div class="modal-header header-part mb-5 mb-lg-6 pb-5 pb-lg-6 mx-3 mx-lg-4">
          <h4 class="modal-title">Select Token</h4>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
        </div>
        <div class="modal-body d-flex flex-column">
          <form method="POST" class="search__form_modal d-none d-md-flex mb-5 mb-lg-6 mx-2 mx-lg-4">
            <div class="alt_form d-center gap-1 bg1-opty p-1 ps-6 ps-lg-8 cus-border cus-rounded-1 w-100">
              <input type="text" name="search__text" placeholder="Search" required />
              <button type="submit" class="p1-bg rounded-3 d-center box_10" name="search__submit">
                <span class="material-symbols-outlined fs-four n0-fixed">
                  search
                </span>
              </button>
            </div>
          </form>
          <div class="token_content d-flex flex-column">
            <a href="#" class="d-flex p-2 p-lg-4 cus-rounded-1 transition">
              <div class="flex-fill d-flex align-items-center gap-4 gap-lg-5 gap-xxl-6">
                <img src="assets/images/bitcoin_lg.png" class="box_12" alt="icon" />
                <div class="d-flex flex-column gap-1">
                  <span class="fs-five fw-medium">BTC</span>
                  <span class="fs-seven">Bitcoin</span>
                </div>
              </div>
              <div class="d-flex flex-column gap-1 align-items-end">
                <span class="fs-six-up">215.3 USDT</span>
                <div class="s1-color d-flex align-items-center gap-1">
                  <span class="material-symbols-outlined"> show_chart </span>92.4%
                </div>
              </div>
            </a>
            <a href="#" class="d-flex p-2 p-lg-4 cus-rounded-1 transition">
              <div class="flex-fill d-flex align-items-center gap-4 gap-lg-5 gap-xxl-6">
                <img src="assets/images/dogecoin_lg.png" class="box_12" alt="icon" />
                <div class="d-flex flex-column gap-1">
                  <span class="fs-five fw-medium">DOGE</span>
                  <span class="fs-seven">Dogecoin</span>
                </div>
              </div>
              <div class="d-flex flex-column gap-1 align-items-end">
                <span class="fs-six-up">635.89 DOGE</span>
                <div class="s1-color d-flex align-items-center gap-1">
                  <span class="material-symbols-outlined"> show_chart </span>72.6%
                </div>
              </div>
            </a>
            <a href="#" class="d-flex p-2 p-lg-4 cus-rounded-1 transition">
              <div class="flex-fill d-flex align-items-center gap-4 gap-lg-5 gap-xxl-6">
                <img src="assets/images/cardano_lg.png" class="box_12" alt="icon" />
                <div class="d-flex flex-column gap-1">
                  <span class="fs-five fw-medium">ADA</span>
                  <span class="fs-seven">Cardano</span>
                </div>
              </div>
              <div class="d-flex flex-column gap-1 align-items-end">
                <span class="fs-six-up">546.7 ADA</span>
                <div class="s3-color d-flex align-items-center gap-1">
                  <span class="material-symbols-outlined"> show_chart </span>55.3%
                </div>
              </div>
            </a>
            <a href="#" class="d-flex p-2 p-lg-4 cus-rounded-1 transition">
              <div class="flex-fill d-flex align-items-center gap-4 gap-lg-5 gap-xxl-6">
                <img src="assets/images/bnb.png" class="box_12" alt="icon" />
                <div class="d-flex flex-column gap-1">
                  <span class="fs-five fw-medium">BNB</span>
                  <span class="fs-seven">Binance</span>
                </div>
              </div>
              <div class="d-flex flex-column gap-1 align-items-end">
                <span class="fs-six-up">7845.9 BNB</span>
                <div class="s2-color d-flex align-items-center gap-1">
                  <span class="material-symbols-outlined"> show_chart </span>42.2%
                </div>
              </div>
            </a>
            <a href="#" class="d-flex p-2 p-lg-4 cus-rounded-1 transition">
              <div class="flex-fill d-flex align-items-center gap-4 gap-lg-5 gap-xxl-6">
                <img src="assets/images/bitcoin_lg.png" class="box_12" alt="icon" />
                <div class="d-flex flex-column gap-1">
                  <span class="fs-five fw-medium">CHAIN</span>
                  <span class="fs-seven">Linkchain</span>
                </div>
              </div>
              <div class="d-flex flex-column gap-1 align-items-end">
                <span class="fs-six-up">66.75 CHAIN</span>
                <div class="s2-color d-flex align-items-center gap-1">
                  <span class="material-symbols-outlined"> show_chart </span>33.3%
                </div>
              </div>
            </a>
          </div>

          <div class="mx-2 mx-lg-4 cus-border-dashed top border-color-30 mt-2 pt-5 pt-lg-6">
            <button type="button"
              class="btn_box w-100 mt-2 py-2 py-lg-3 px-4 gap-3 cus-rounded-1 cus-border border-color">
              <svg xmlns="http://www.w3.org/2000/svg" width="18" height="17" viewBox="0 0 18 17" fill="none">
                <path
                  d="M6.99147 9.33073C7.44981 9.33073 7.82481 9.70573 7.82481 10.1641C7.82481 10.6224 7.44981 10.9974 6.99147 10.9974C6.53314 10.9974 6.15814 10.6224 6.15814 10.1641C6.15814 9.70573 6.53314 9.33073 6.99147 9.33073ZM6.99147 7.66406C5.60814 7.66406 4.49147 8.78073 4.49147 10.1641C4.49147 11.5474 5.60814 12.6641 6.99147 12.6641C8.37481 12.6641 9.49147 11.5474 9.49147 10.1641C9.49147 8.78073 8.37481 7.66406 6.99147 7.66406ZM14.0748 5.9974L14.9831 3.98906L16.9915 3.08073L14.9831 2.1724L14.0748 0.164062L13.1665 2.1724L11.1581 3.08073L13.1665 3.98906L14.0748 5.9974ZM16.3915 9.0974L15.7415 7.66406L15.0915 9.0974L13.6581 9.7474L15.0915 10.3974L15.7415 11.8307L16.3915 10.3974L17.8248 9.7474L16.3915 9.0974ZM12.1998 10.1641C12.1998 10.0641 12.1998 9.95573 12.1915 9.85573L13.8081 8.63073L11.7248 5.0224L9.85814 5.80573C9.69147 5.6974 9.50814 5.58906 9.32481 5.4974L9.07481 3.4974H4.90814L4.65814 5.50573C4.4748 5.5974 4.2998 5.70573 4.1248 5.81406L2.25814 5.0224L0.174805 8.63073L1.79147 9.85573C1.78314 9.95573 1.78314 10.0641 1.78314 10.1641C1.78314 10.2641 1.78314 10.3724 1.79147 10.4724L0.174805 11.6974L2.25814 15.3057L4.1248 14.5224C4.29147 14.6307 4.4748 14.7391 4.65814 14.8307L4.90814 16.8307H9.07481L9.32481 14.8224C9.50814 14.7307 9.68314 14.6307 9.85814 14.5141L11.7248 15.2974L13.8081 11.6891L12.1915 10.4641C12.1998 10.3724 12.1998 10.2641 12.1998 10.1641ZM11.0165 13.1974L9.57481 12.5891C9.10814 13.0891 8.49147 13.4557 7.79981 13.6141L7.5998 15.1641H6.38314L6.19147 13.6141C5.4998 13.4557 4.88314 13.0891 4.41647 12.5891L2.9748 13.1974L2.36647 12.1391L3.60814 11.1974C3.50814 10.8724 3.45814 10.5307 3.45814 10.1724C3.45814 9.81406 3.50814 9.4724 3.60814 9.1474L2.36647 8.20573L2.9748 7.1474L4.41647 7.75573C4.88314 7.25573 5.4998 6.88906 6.19147 6.73073L6.38314 5.16406H7.60814L7.79981 6.71406C8.49147 6.8724 9.10814 7.23906 9.57481 7.73906L11.0165 7.13073L11.6248 8.18906L10.3831 9.13073C10.4831 9.45573 10.5331 9.7974 10.5331 10.1557C10.5331 10.5141 10.4831 10.8557 10.3831 11.1807L11.6248 12.1224L11.0165 13.1974Z"
                  fill="white" />
              </svg>Manage Token
            </button>
          </div>
        </div>
      </div>
    </div>
  </div>

  <!-- Modal -->
<div class="modal fade" id="statusModal" tabindex="-1" aria-labelledby="statusModalLabel" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content p-4">
      <div class="modal-header border-0">
        <h5 class="modal-title" id="statusModalLabel">Rejection Reason</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
      </div>
      <div class="modal-body mt-6" id="rejectonReasonModal">
      </div>
    </div>
  </div>
</div>



  <!-- Footer Area Start -->
  <footer class="footer">
    <div class="col-12">
      <div class="footer__copyright justify-content-center justify-content-sm-between gap-10 row-gap-2">
        <p class="copyright text-center">
          Copyright © <span id="copyYear"></span>. All Rights Reserved
        </p>
      </div>
    </div>
  </footer>
  <!-- Footer Area End -->
    <script>
        const assetPrices = {};
        var transactions = <?php echo json_encode($transactions); ?>;
        console.log('ja_transactions', transactions);  
    </script>
  <!-- ==== js dependencies start ==== -->
  <script src="assets/js/plugins/plugins.js"></script>
  <script src="assets/js/plugins/apexcharts.min.js"></script>
  <script src="//cdn.quilljs.com/1.3.6/quill.min.js"></script>
  <script src="assets/js/plugins/plugin-custom.js"></script>
  <script src="assets/js/main.js"></script>
  <script src="assets/js/plugins/custom_apexcharts.js"></script>

  <!-- Add this JavaScript -->
<script>
  document.addEventListener('DOMContentLoaded', function () {
    // Get the balances from PHP (e.g., from PHP variables passed into JavaScript)
    var btcBalance = <?php echo json_encode($btc_balance); ?>;
    var ethBalance = <?php echo json_encode($eth_balance); ?>;
    var trxBalance = <?php echo json_encode($trx_balance); ?>;
    var usdtBalance = <?php echo json_encode($usdt_balance); ?>;

    // Set initial balance in the modal (assuming BTC is selected by default)
    document.getElementById('selectedFromCurrency').textContent = 'BTC';
    document.getElementById('selectedToCurrencyLabel').textContent = 'BTC';
    document.querySelector('.balance-text').textContent = 'Balance: ' + btcBalance + ' BTC';
    document.getElementById('selectedToCurrencyLogo').src = 'assets/images/bitcoin_mid.png';
    document.getElementById('selectedToCurrencyLabel').textContent = 'BTC';

    // Set the initial max amount for the "From" input field
    document.querySelector('input[name="from"]').max = btcBalance;

    // Handle dropdown selection
    const dropdownItems = document.querySelectorAll('.dropdown-item');

    dropdownItems.forEach(item => {
      item.addEventListener('click', function () {
        const currency = this.getAttribute('data-currency');
        const imgSrc = this.getAttribute('data-img');

        // Update "From" currency (selectedFromCurrency)
        document.getElementById('selectedFromCurrency').textContent = currency;
        document.getElementById('selectedFromCurrency').previousElementSibling.src = `assets/images/${imgSrc}`;

        // Update "To" currency (selectedToCurrency)
        document.getElementById('selectedToCurrencyLabel').textContent = currency;
        document.getElementById('selectedToCurrencyLogo').src = `assets/images/${imgSrc}`;

        // Clear the "From" input field when currency is changed
        document.querySelector('input[name="from"]').value = '';

        // Update Balance display based on selected currency
        if (currency === 'BTC') {
          document.querySelector('.balance-text').textContent = `Balance: ${btcBalance} BTC`;
          document.querySelector('input[name="from"]').max = btcBalance; // Set max value for BTC
        } else if (currency === 'ETH') {
          document.querySelector('.balance-text').textContent = `Balance: ${ethBalance} ETH`;
          document.querySelector('input[name="from"]').max = ethBalance; // Set max value for ETH
        } else if (currency === 'TRX') {
          document.querySelector('.balance-text').textContent = `Balance: ${trxBalance} TRX`;
          document.querySelector('input[name="from"]').max = trxBalance; // Set max value for TRX
        } else if (currency === 'USDT') {
          document.querySelector('.balance-text').textContent = `Balance: ${usdtBalance} USDT`;
          document.querySelector('input[name="from"]').max = usdtBalance; // Set max value for USDT
        }
      });
    });

    // Handle Withdraw Crypto button click
    document.getElementById('withdrawCryptoBtn').addEventListener('click', function () {
        var amount = document.getElementById('withdrawAmount').value;
        var address = document.getElementById('withdrawAddress').value;
        if(amount && address)
        $.ajax({
            type: "POST",
            url: 'withdraw/withdraw.php',
            data: {
                "amount": $('#withdrawAmount').val(), 
                "address": $('#withdrawAddress').val(), 
                "user_id": $('#userId').val(),
                "asset": $('#selectedFromCurrency').text(),
                "status": "Pending"
            },
            success: function(response){
                if(response == "Success"){
                    // Hide the withdraw form
                    document.getElementById('withdrawForm').classList.add('d-none');
                    document.getElementById('withdrawClose').classList.add('d-none');
                    // Show the "Order Processing" message
                    document.getElementById('orderProcessingMessage').classList.remove('d-none');
                    document.getElementById('withdrawCloseSuccess').classList.remove('d-none');
                }
                else {
                    alert('Withdraw Failed');
                }
            }
        });
        else {
            alert('Fill out all fields');
        }

      
    });

    document.getElementById('withdrawCloseSuccess').addEventListener('click', function () {
        location.reload();
    });

    // Input validation to ensure the entered amount doesn't exceed the balance
    document.querySelector('input[name="from"]').addEventListener('input', function () {
      const maxAmount = parseFloat(this.max);
      const enteredAmount = parseFloat(this.value);

      if (enteredAmount > maxAmount) {
        // If the entered amount exceeds the balance, reset the input to the max value
        this.value = maxAmount;
      }
    });
  });

    async function getAssetPrices() {
        try {
            // API endpoint for CoinCap
            const apiUrl = 'https://api.coincap.io/v2/assets';

            // Fetch data from CoinCap API
            const response = await fetch(apiUrl);

            // Check if the response is ok
            if (!response.ok) {
                throw new Error('Failed to fetch asset data');
            }

            const data = await response.json();

            // Create a dictionary of asset prices
            data.data.forEach(asset => {
                assetPrices[asset.symbol] = parseFloat(asset.priceUsd);
            });

        } catch (error) {
            console.error('Error fetching asset values:', error);
            // Optionally, display an error message in the UI if necessary
        }
    }

    function updateCssProgress () {
        // cssProgress bar
        $('.cssProgress').each(function () {
            var self = $(this);
            var progress_bar = self.find('.cssProgress-bar');
            var progress_label = self.siblings('.cssProgress-label');
            var progress_value = progress_bar.data('percent');
            // var percentage = parseInt(progress_value, 10) + '%';
            var percentage = parseFloat(progress_value).toFixed(2) + '%';
            progress_bar.css({
                'width': '0%',
                'transition': 'none',
                '-webkit-transition': 'none',
                '-moz-transition': 'none'
            });
        
            progress_bar.animate({
                width: percentage
            }, {
                duration: 1000,
                step: function (x) {
                    progress_label.text(x.toFixed(2) + '%');
                }
            });
        });
    }

    // Function to fetch cryptocurrency prices and update the values
    async function updateAssetValues() {
        try {
            // API endpoint for CoinCap
            const apiUrl = 'https://api.coincap.io/v2/assets';

            // Fetch data from CoinCap API
            const response = await fetch(apiUrl);

            // Check if the response is ok
            if (!response.ok) {
                throw new Error('Failed to fetch asset data');
            }

            const data = await response.json();

            // Create a dictionary of asset prices
            data.data.forEach(asset => {
                assetPrices[asset.symbol] = parseFloat(asset.priceUsd);
            });

            console.log('Asset Prices:', assetPrices);

            // Get the wallet balances (dynamically injected from PHP)
            const btcBalance = <?php echo $wallet['btc_balance']; ?>;
            const ethBalance = <?php echo $wallet['eth_balance']; ?>;
            const trxBalance = <?php echo $wallet['trx_balance']; ?>;
            const usdtBalance = <?php echo $wallet['usdt_balance']; ?>;

            // Calculate the USD values for each asset
            const btcValue = (btcBalance * assetPrices.BTC).toFixed(2);
            const ethValue = (ethBalance * assetPrices.ETH).toFixed(2);
            const trxValue = (trxBalance * assetPrices.TRX).toFixed(2);
            const usdtValue = (usdtBalance * assetPrices.USDT).toFixed(2);

            // Calculate the total balance in USD
            const totalBalance = (
                parseFloat(btcValue) + parseFloat(ethValue) + parseFloat(trxValue) + parseFloat(usdtValue)
            ).toFixed(2);

            // Update the DOM with the calculated values
            document.querySelector('.btc-value').innerText = `$${btcValue}`;
            document.querySelector('.eth-value').innerText = `$${ethValue}`;
            document.querySelector('.trx-value').innerText = `$${trxValue}`;
            document.querySelector('.usdt-value').innerText = `$${usdtValue}`;
            document.querySelector('.total-balance').innerText = `$${totalBalance}`;

            // Calculate the percentage of each asset in the total balance
            const btcPercent = ((parseFloat(btcValue) / totalBalance) * 100).toFixed(2);
            console.log('btcPercent', btcPercent);
            const ethPercent = ((parseFloat(ethValue) / totalBalance) * 100).toFixed(2);
            const trxPercent = ((parseFloat(trxValue) / totalBalance) * 100).toFixed(2);
            const usdtPercent = ((parseFloat(usdtValue) / totalBalance) * 100).toFixed(2);

            // Update the DOM with the calculated values
            document.getElementById('btcPercent').innerText = `${btcPercent}%`;
            document.getElementById('btcPercentProgress').setAttribute('data-percent', `${btcPercent}`);
            document.getElementById('ethPercent').innerText = `${ethPercent}%`;
            document.getElementById('ethPercentProgress').setAttribute('data-percent', `${ethPercent}`);
            document.getElementById('trxPercent').innerText = `${trxPercent}%`;
            document.getElementById('trxPercentProgress').setAttribute('data-percent', `${trxPercent}`);
            document.getElementById('usdtPercent').innerText = `${usdtPercent}%`;
            console.log('usdtPercent', usdtPercent);
            document.getElementById('usdtPercentProgress').setAttribute('data-percent', `${usdtPercent}`);
            updateCssProgress();

            if (document.querySelector("#fin_total_area")) {
                showChart('BTC');
            }

        } catch (error) {
            console.error('Error fetching asset values:', error);
            // Optionally, display an error message in the UI if necessary
        }
    }

    // Call the function on page load
    window.onload = updateAssetValues;

    function showChart(cryptoAsset) {
        if (!document.querySelector("#fin_total_area"))
            return false;
        $('#assetName').html(cryptoAsset);
        var subTransactions = transactions.filter(transaction => transaction.asset === cryptoAsset).sort((a, b) => new Date(a.date_time) - new Date(b.date_time));
        var chartData = [];
        let amount = 0;
        for(let i=0; i<subTransactions.length; i++) {
            if(subTransactions[i].status === 'Successful' || subTransactions[i].status === 'Pending') {
                var subAmount = Number(subTransactions[i].amount);
                amount = subTransactions[i].transaction_type === 'Deposit' ? amount + subAmount : amount - subAmount;
            }
            console.log('ja_assetPrice', assetPrices);  
            const price = (amount * assetPrices[cryptoAsset]).toFixed(2);
            console.log('ja_amount', amount, price);
            chartData.push([subTransactions[i].date_time, price]);
        }
        console.log('ja_chartdata', chartData);

        var options = {
            series: [{
                'name': cryptoAsset,
                data: chartData
            }],
            ...optionsFinTotal
        }
        if(chartFinTotal) {
            chartFinTotal.updateSeries([{
                name: cryptoAsset,
                data: chartData
            }]);
        }
        else {
            chartFinTotal = new ApexCharts(document.querySelector("#fin_total_area"), options);
            chartFinTotal.render();
        }
    }    

    var myModal = new bootstrap.Modal(document.getElementById('statusModal'));

    function openModal() {
        myModal.show();
    }

    function closeModal() {
        myModal.hide();
    }

    function openStatusModal(transactionId) {
        var transactionSelected = transactions.find(transaction => transaction.id == transactionId);
        if(transactionSelected.status === 'Rejected') {
            $('#rejectonReasonModal').html(transactionSelected.rejection_reason ?? 'Rejection reason is not available.');
            openModal();
        }
    }
</script>
</body>

</html>