<?php
session_start(); // Start the session
include('database.php'); // Include the database connection

// Initialize variables for login credentials
$email = $password = "";

// Handle form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Get form data
    $email = $_POST['email_ad'];
    $password = $_POST['password'];

    // Check if the email exists in the database
    $stmt = $conn->prepare("SELECT * FROM users WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        // User exists, now check if the password matches
        $user = $result->fetch_assoc();
        if (password_verify($password, $user['password'])) {
            // Password is correct, redirect to dashboard
            $_SESSION['user_id'] = $user['id']; // Store user session data
            $popup_type = "success";
            $popup_message = "Login successful! Redirecting to dashboard...";
            header("refresh:2;url=dashboard.php"); // Redirect after 2 seconds
        } else {
            // Incorrect password
            $popup_type = "error";
            $popup_message = "Incorrect password! Please check and try again.";
        }
    } else {
        // Email not found
        $popup_type = "error";
        $popup_message = "Email not registered. Please check and try again.";
    }

    // Close the statement
    $stmt->close();
}

// Close the database connection
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <!-- required meta -->
    <meta charset="UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="keywords" content="Crypto Portfolio - Log In" />
    <meta name="description" content="Crypto Portfolio - Log In" />
    <title>Crypto Portfolio - Log In</title>
    <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
    <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
    <link rel="stylesheet" href="assets/css/style.min.css" />

    <!-- SweetAlert2 CDN -->
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>

<body>
    <!-- Main Body Start -->
    <div class="sign_area login_bg n0-bg d-flex justify-content-center align-items-center">
        <div class="container">
            <div class="row align-items-center justify-content-between">
                <div class="d-none d-md-flex col-md-6 col-lg-5 col-xxl-4 justify-content-end">
                    <div class="login_thumb">
                        <img src="assets/images/login.png" class="max-xxl-un" alt="image" />
                    </div>
                </div>
                <div class="col-md-6 col-lg-6">
                    <div class="sign__content ms-md-5 ms-xxl-0 pt-120 pb-120">
                        <div class="head_part d-flex flex-column gap-4">
                            <h3>Welcome Back!</h3>
                            <p>Sign in to your account to have access over your crypto portfolio</p>
                        </div>
                        <form class="contact__form mt-8 mt-lg-10" method="POST" id="loginForm">
                            <div class="d-flex flex-column gap-5">
                                <div class="single-input">
                                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="email_ad">Enter Your Email</label>
                                    <input type="email" class="fs-seven py-2 py-lg-3 px-3 px-lg-6" id="email_ad" name="email_ad" placeholder="Enter Your Email..." required />
                                </div>
                                <div class="single-input">
                                    <label class="fs-six-up fw-medium mb-2 mb-sm-4" for="password">Enter Your Password</label>
                                    <div class="input-pass">
                                        <input type="password" class="fs-seven py-2 py-sm-3 ps-3 ps-lg-5 ps-lg-6 pe-10 pe-lg-13" name="password" id="password" placeholder="Enter Your Password..." required />
                                        <span class="password-eye-icon"></span>
                                    </div>
                                </div>
                                <div class="part">
                                    <a href="#" class="d-flex justify-content-end fs-seven p1-color">Forget password</a>
                                    <p>Don’t have an account? <a href="signup.php" class="p1-color fw-semibold">Signup</a></p>
                                </div>
                            </div>
                            <div class="d-flex gap-5 gap-lg-6 mt-7 mt-lg-8">
                                <button type="submit" class="btn_box py-2 py-lg-3 px-5 px-lg-6 cus-rounded-1 cus-border border-color">Login</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Main Body End -->

    <?php if (isset($popup_type) && isset($popup_message)): ?>
        <script>
            Swal.fire({
                icon: '<?php echo $popup_type; ?>',
                title: '<?php echo $popup_message; ?>',
                showConfirmButton: false,
                timer: 2000 // Auto-close after 2 seconds
            });
        </script>
    <?php endif; ?>

    <!-- JS dependencies -->
    <script src="assets/js/plugins/plugins.js"></script>
    <script src="assets/js/plugins/apexcharts.min.js"></script>
    <script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
    <script src="assets/js/plugins/custom_apexcharts.js"></script>
    <script src="assets/js/plugins/plugin-custom.js"></script>
    <script src="assets/js/main.js"></script>
</body>

</html>
