<?php
include('database.php');

if ($_SERVER["REQUEST_METHOD"] === "POST") {
    $token = $_POST['token'];
    $newPassword = password_hash($_POST['password'], PASSWORD_BCRYPT);

    // Check if token is valid
    $stmt = $conn->prepare("SELECT id FROM users WHERE reset_token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        // Update password and remove token
        $stmt = $conn->prepare("UPDATE users SET password = ?, reset_token = NULL WHERE reset_token = ?");
        $stmt->bind_param("ss", $newPassword, $token);
        $stmt->execute();
        echo "Password reset successful!";
    } else {
        echo "Invalid token!";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reset Password</title>
    <!-- <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet"> -->
    <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
    <link rel="stylesheet" href="assets/css/style.min.css" />
    <style>
        body {
            background: #f8f9fa;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }
        .card {
            border-radius: 15px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.1);
        }
    </style>
</head>
<body>

<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <div class="card p-4">
                <div class="card-body text-center">
                    <h3 class="mb-3">Reset Your Password</h3>
                    <p class="text-muted mb-2">Enter your new password below</p>
                    <form id="resetPasswordForm">
                        <input type="hidden" id="token" value="<?php echo $_GET['token']; ?>">
                        <div class="mb-3">
                            <input type="password" id="password" class="form-control" placeholder="New Password" required>
                        </div>
                        <div class="mb-3">
                            <input type="password" id="confirmPassword" class="form-control" placeholder="Confirm Password" required>
                        </div>
                        <button type="submit" class="btn btn-primary w-100 btn_box py-2 py-lg-3 px-5 px-lg-6 cus-rounded-1 cus-border border-color">Reset Password</button>
                    </form>
                    <div class="mt-3">
                        <a href="login.php" class="text-muted">Back to Login</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- ==== js dependencies start ==== -->
<script src="assets/js/plugins/plugins.js"></script>
<script src="assets/js/plugins/apexcharts.min.js"></script>
<script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
<script src="assets/js/plugins/custom_apexcharts.js"></script>
<script src="assets/js/plugins/plugin-custom.js"></script>
<script src="assets/js/main.js"></script>

<script>
    $("#resetPasswordForm").submit(function(e) {
        e.preventDefault();
        let password = $("#password").val();
        let confirmPassword = $("#confirmPassword").val();
        let token = $("#token").val();

        if (password !== confirmPassword) {
            alert("Passwords do not match!");
            return;
        }

        $.post("reset_password.php", { token: token, password: password }, function(response) {
            if (response.includes("successful")) {
                alert('Password reset successful! You can now log in.');
                window.location.href = "login.php";
            }
        });
    });
</script>

</body>
</html>


