<?php
session_start();

include('database.php');

if (!isset($_SESSION['user_id'])) {
    // If the user is not logged in, redirect to login page
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

// Fetch user details (name and surname) from the database
$stmt = $conn->prepare("SELECT first_name, last_name FROM users WHERE id = ?");
$stmt->bind_param("i", $user_id); 
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    // Assign user name and surname to variables
    $first_name = $user['first_name'];
    $last_name = $user['last_name'];
} else {
    header("Location: login.php");
    exit();
}

// Fetch wallet addresses from the shared_wallets table
$walletQuery = $conn->prepare("SELECT btc_wallet, eth_wallet, trx_wallet, usdt_wallet FROM shared_wallets LIMIT 1");
$walletQuery->execute();
$walletResult = $walletQuery->get_result();
$wallet = $walletResult->fetch_assoc();  // Assuming there's only one row in shared_wallets table

$btc_address = $wallet['btc_wallet'];
$eth_address = $wallet['eth_wallet'];
$trx_address = $wallet['trx_wallet'];
$usdt_address = $wallet['usdt_wallet'];

// Fetch the latest transactions (if needed)
$transactionQuery = $conn->prepare("SELECT * FROM transactions WHERE user_id = ? ORDER BY date_time DESC LIMIT 10");
$transactionQuery->bind_param("i", $user_id);
$transactionQuery->execute();
$transactionResult = $transactionQuery->get_result();

$transactions = [];
while ($transaction = $transactionResult->fetch_assoc()) {
    $transactions[] = $transaction;  
}

// Close connections
$walletQuery->close();
$transactionQuery->close();
$stmt->close();
$conn->close();
?>


<!DOCTYPE html>
<html lang="en">

<head>
  <!-- required meta -->
  <meta charset="UTF-8" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <!-- #keywords -->
  <meta name="keywords" content="boot, Bootstrap, Forex and Stock Broker HTML Template" />
  <!-- #description -->
  <meta name="description" content="Forex and Stock Broker HTML Template" />
  <!-- #title -->
  <title>FinVista - Web3 and Finance Dashboard Template</title>
  <!-- #favicon -->
  <link rel="shortcut icon" href="assets/images/fav.png" type="image/x-icon" />
  <!-- ==== css dependencies start ==== -->
  <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet" />
  <link rel="stylesheet" href="assets/css/style.min.css" />
</head>

<body>
  <!--  Preloader  -->
  <div class="preloader">
    <span class="loader"></span>
  </div>
  <!-- end preloader -->

  <!-- Scroll To Top Start-->
  <button class="scrollToTop d-none d-md-flex d-center rounded" aria-label="scroll Bar Button">
    <i class="mat-icon fs-four nb4-color ti ti-arrow-up"></i>
  </button>
  <!-- Scroll To Top End -->

  <!-- header-section start -->

  <div class="two-column_logo d-none gap-3">
    <a href="dashboard.php">
      <img src="assets/images/text_logo.png" class="logo_light" alt="Logo " />
      <img src="assets/images/text_logo_dark.png" class="logo_dark" alt="Logo" />
    </a>
    <span class="material-symbols-outlined close_nav p-1 d-xl-none">
      close
    </span>
  </div>

  <div class="manu-wrapper">
    <!--header-section start-->
    <header class="top-menu">
      <nav
        class="top-menu__content py-5 py-xxl-8 px-3 px-lg-4 px-xxl-6 d-flex align-items-center justify-content-between gap-6">
        <div class="top-menu__left d-flex gap-3 gap-xxl-6">
          <button class="nav_tab d-center cus-rounded-2 left d-none d-md-flex">
            <span class="material-symbols-outlined fs-two n700-color">
              menu
            </span>
          </button>
          <button class="nav_tab second p1-bg d-center cus-rounded-2 left">
            <span class="navbar-toggle-btn box_15 overflow-hidden cus-border-dashed rounded-circle d-md-none">
              <span></span>
              <span></span>
              <span></span>
              <span></span>
            </span>
          </button>
          <div class="company-short-logo d-center justify-content-between gap-2 d-xl-none">
            <a href="dashboard.php" class="logo_area">
              <span class="logo-xl">
                <img src="assets/images/short_logo_light.png" class="logo" alt="Logo" />
              </span>
              <span class="logo-xl logo_dark">
                <img src="assets/images/short_logo_dark.png" class="logo" alt="Logo" />
              </span>
            </a>
          </div>
          <div class="d-flex align-items-center gap-3">
            <form method="POST" class="search__form_nav d-none d-md-flex">

            </form>
          </div>
        </div>
        <div class="top-menu__right d-flex gap-1 gap-md-3 gap-xxl-6 z-0 align-items-center">
          <div class="btn_box btn_alt box_12 cus-border nav_search_short d-md-none">
            <span class="material-symbols-outlined fs-four"> search </span>
          </div>
          <div class="toggle-switch btn_box btn_alt box_12 cus-border">
            <input type="checkbox" class="checkbox" id="checkbox" />
            <label for="checkbox" class="checkbox-label">
              <span class="material-symbols-outlined fs-four">
                dark_mode
              </span>
              <span class="material-symbols-outlined fs-four light_mode">
                light_mode
              </span>
            </label>
          </div>
          <div class="position-relative notification_area">
            <div class="notification_icon btn_box btn_alt box_12 cus-border d-center">
              <span class="material-symbols-outlined fs-four">
                notifications
              </span>
            </div>
            <ul class="notification_nav hover-scroll d-flex flex-column gap-4 n0-bg px-4 px-lg-5 py-4 cus-rounded-1">
              <li>
                <div class="d-flex align-items-center gap-3">
                  <a href="#" class="user_profile_thumb">
                    <img src="assets/images/user_profile10.png" class="rounded-circle" alt="image" />
                  </a>
                  <div class="user_profile_title flex-fill">
                    <a href="#">Theresa Webb</a>
                    <p class="mt-1 fs-eight">just ideas for next time</p>
                  </div>
                  <div class="notification just_active d-center flex-column">
                    <span class="notification__count box_6 rounded-circle d-center fs-eight">5</span>
                    <span class="notification__time fs-eight">4m</span>
                  </div>
                </div>
              </li>
              <li>
                <div class="d-flex align-items-center gap-3">
                  <a href="#" class="user_profile_thumb">
                    <img src="assets/images/user_profile9.png" class="rounded-circle" alt="image" />
                  </a>
                  <div class="user_profile_title flex-fill">
                    <a href="#">Bessie Cooper</a>
                    <p class="mt-1 fs-eight">omg, this is amazing</p>
                  </div>
                  <div class="notification just_active d-center flex-column">
                    <span class="notification__count box_6 rounded-circle d-center fs-eight">1</span>
                    <span class="notification__time fs-eight">5m</span>
                  </div>
                </div>
              </li>
            </ul>
          </div>

          <div class="lang_nav box_12 position-relative cus-border rounded-3">
            <div onclick="toggleDropNav()" class="nav_dropdown_btn btn_box btn_alt box_12 d-center bg1-opty">
              <img src="assets/images/unitedkingdom.png" alt="United Kingdom" class="flag-img rounded-circle box_6" />
              <span class="nav_lang d-none">United Kingdom</span>
            </div>
            <ul class="lang_nav_list hover-scroll position-absolute py-1 py-lg-2 n0-bg cus-rounded-1">
              <li onclick="selectOptionNav('United Kingdom', 'assets/images/united-kingdom.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/unitedkingdom.png" alt="United Kingdom" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">United Kingdom</span>
              </li>
              <li onclick="selectOptionNav('Canada', 'assets/images/canada.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/canada.png" alt="Canada" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">Canada</span>
              </li>
              <li onclick="selectOptionNav('Australia', 'assets/images/australia.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/australia.png" alt="Australia" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">Australia</span>
              </li>
              <li onclick="selectOptionNav('France', 'assets/images/france.png')"
                class="d-flex align-items-center gap-2 px-3 px-lg-5 py-2">
                <img src="assets/images/france.png" alt="France" class="flag-img rounded-circle box_5" />
                <span class="nav_lang">France</span>
              </li>
            </ul>
          </div>


          <div class="user-account box_12 position-relative">
            <div class="profile-nav">
              <img src="assets/images/user.png" class="box_12 cus-rounded-1" alt="img" />
            </div>
            <ul class="user-profile hover-scroll n0-bg d-flex flex-column gap-1 p-3 cus-rounded-1">
              <li>
                <a href="settings.php" class="d-flex align-items-center gap-2 p1-color"><span
                    class="material-symbols-outlined fs-four">
                    person </span>My Account</a>
              </li>
              <li>
                <a href="log_out.html class=" d-flex align-items-center gap-2 p1-color"><span
                    class="material-symbols-outlined fs-four">
                    logout </span>Log Out</a>
              </li>
            </ul>
          </div>
        </div>
      </nav>
    </header>

    <!-- aside start -->
    <div class="company-logo d-center justify-content-between gap-2">
      <a href="dashboard.php" class="logo_area">
        <span class="logo-xl">
          <img src="assets/images/logo_light.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_light.png" class="short_logo" alt="Logo" />
        </span>
        <span class="logo-xl logo_dark">
          <img src="assets/images/logo_dark.png" class="full_logo" alt="Logo" />
          <img src="assets/images/short_logo_dark.png" class="short_logo" alt="Logo" />
        </span>
      </a>
      <span class="material-symbols-outlined close_nav p-1 d-xl-none">
        close
      </span>
    </div>

    <aside class="aside-wrapper">
      <div class="main-menu">
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold">Dashboard</li>
          <li class="nav_item">
            <a href="dashboard.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                house
              </span>
              <span class="nav_text">Dashboard</span>
            </a>
          </li>
          <li class="nav_item">
            <a href="wallet.php" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                layers
              </span>
              <span class="nav_text">Wallets</span>
            </a>
          </li>
          <li class="nav_dropdown">
            <button class="dropdown_arrow">
              <span class="material-symbols-outlined fs-four-up">
                account_circle
              </span>
              <span class="nav_text">Account</span>
            </button>
            <ul class="nav_dropdown-menu">
              <li><a href="settings.php">Settings</a></li>
              <li><a href="password.php">Password</a></li>
            </ul>
          </li>
          <li class="nav_item">
            <a href="contact.html" class="nav_link">
              <span class="material-symbols-outlined fs-four-up">
                phone
              </span>
              <span class="nav_text">Contact Us</span>
            </a>
          </li>
        </ul>
        <ul class="main-menu__part">
          <li class="main-menu__title fw-semibold"></li>
          <li>
            <a href="logout.html" class="nav_link">
              <span class="material-symbols-outlined p1-color fs-four-up">
                logout
              </span>
              <span href="log_out.html" class="nav_text">Log out</span>
            </a>
          </li>
        </ul>

        <ul class="main-menu__part logout_area mt-auto d-none">
          <li>
            <a href="logout.html"><span class="material-symbols-outlined p1-color">
                logout
              </span></a>
          </li>
        </ul>
        
      </div>
    </aside>

    <!-- aside end -->
  </div>
  <div class="clone_area d-center"></div>
  <!-- header-section end -->

  <!-- main-body start -->
  <div class="main-content overflow-hidden">
    <div class="container-fluid">
      <div class="row">
        <div class="col-12">
          <div class="top-area flex-wrap d-center justify-content-between gap-8 row-gap-3">
            <h2>Crypto Wallets</h2>
          </div>
        </div>
      </div>

      <div class="row g-6">
        <div class="col-sm-6 col-xxl-3">
            <div class="n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
                <div class="header-part d-center justify-content-between pb-5 pb-lg-6 mb-5 mb-lg-6">
                    <div class="d-flex align-items-center gap-3">
                        <div class="d-flex">
                            <img src="assets/images/bitcoin_mid.png" class="box_8 rounded-circle" alt="..." />
                        </div>
                        <h4>Bitcoin</h4>
                    </div>
                </div>
                <div class="d-flex align-items-center justify-content-between position-relative">
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Price</span>
                        <h4 class="fw-normal n700-color" id="bitcoin-price">---</h4>
                    </div>
                    <div class="v-line dashed cus-border-dashed right h-100 border-color-30"></div>
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Market Cap</span>
                        <h4 class="fw-normal n700-color" id="bitcoin-market-cap">---</h4>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-sm-6 col-xxl-3">
            <div class="n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
                <div class="header-part d-center justify-content-between pb-5 pb-lg-6 mb-5 mb-lg-6">
                    <div class="d-flex align-items-center gap-3">
                        <div class="d-flex">
                            <img src="assets/images/ethereum_mid.png" class="box_8 rounded-circle" alt="..." />
                        </div>
                        <h4>Ethereum</h4>
                    </div>
                </div>
                <div class="d-flex align-items-center justify-content-between position-relative">
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Price</span>
                        <h4 class="fw-normal n700-color" id="ethereum-price">---</h4>
                    </div>
                    <div class="v-line dashed cus-border-dashed right h-100 border-color-30"></div>
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Market Cap</span>
                        <h4 class="fw-normal n700-color" id="ethereum-market-cap">---</h4>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-sm-6 col-xxl-3">
            <div class="n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
                <div class="header-part d-center justify-content-between pb-5 pb-lg-6 mb-5 mb-lg-6">
                    <div class="d-flex align-items-center gap-3">
                        <div class="d-flex">
                            <img src="assets/images/tron_med.png" class="box_8 rounded-circle" alt="..." />
                        </div>
                        <h4>Tron (TRX)</h4>
                    </div>
                </div>
                <div class="d-flex align-items-center justify-content-between position-relative">
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Price</span>
                        <h4 class="fw-normal n700-color" id="tron-price">---</h4>
                    </div>
                    <div class="v-line dashed cus-border-dashed right h-100 border-color-30"></div>
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Market Cap</span>
                        <h4 class="fw-normal n700-color" id="tron-market-cap">---</h4>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-sm-6 col-xxl-3">
            <div class="n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
                <div class="header-part d-center justify-content-between pb-5 pb-lg-6 mb-5 mb-lg-6">
                    <div class="d-flex align-items-center gap-3">
                        <div class="d-flex">
                            <img src="assets/images/tether_mid.png" class="box_8 rounded-circle" alt="..." />
                        </div>
                        <h4>Tether (USDT)</h4>
                    </div>
                </div>
                <div class="d-flex align-items-center justify-content-between position-relative">
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Price</span>
                        <h4 class="fw-normal n700-color" id="tether-price">---</h4>
                    </div>
                    <div class="v-line dashed cus-border-dashed right h-100 border-color-30"></div>
                    <div class="d-flex flex-column gap-1">
                        <span class="fs-seven n700-color">Market Cap</span>
                        <h4 class="fw-normal n700-color" id="tether-market-cap">---</h4>
                    </div>
                </div>
            </div>
        </div>
    </div>

      <div class="col-12">
        <div class="table-area overview_list n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
          <div
            class="header-part d-flex flex-nowrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
            <div class="d-flex align-items-center flex-wrap row-gap-3 gap-6 gap-xxl-8 w-100">
              <h4 class="fw-semibold">Crypto Wallets</h4>
            </div>
          </div>
          <div class="table-main three_dot">
          <table>
  <thead>
    <tr>
      <th>Title</th>
      <th>Chain</th>
      <th>Wallet Address</th>
      <th class="justify-content-start">Copy</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>
        <div class="d-flex align-items-center gap-2 gap-lg-3">
          <img src="assets/images/bitcoin_mid.png" class="box_8 rounded-circle" alt="BTC" />
          <span class="fw-medium">Bitcoin (BTC)</span>
        </div>
      </td>
      <td>
        <div class="d-flex flex-column gap-1">
          <span class="fw-medium" id="btc-price">Blockchain</span>
        </div>
      </td>
      <td>
        <span class="fw-medium" id="btc-address"><?php echo $btc_address; ?></span>
      </td>
      <td>
        <button onclick="copyToClipboard('btc-address', this)" class="btn_box btn_alt cus-border border-color py-2 py-lg-3 px-4 w-100">
          Copy
        </button>
      </td>
    </tr>
    <tr>
      <td>
        <div class="d-flex align-items-center gap-2 gap-lg-3">
          <img src="assets/images/ethereum_mid.png" class="box_8 rounded-circle" alt="ETH" />
          <span class="fw-medium">Ethereum (ETH)</span>
        </div>
      </td>
      <td>
        <div class="d-flex flex-column gap-1">
          <span class="fw-medium" id="eth-price">Ethereum</span>
        </div>
      </td>
      <td>
        <span class="fw-medium" id="eth-address"><?php echo $eth_address; ?></span>
      </td>
      <td>
        <button onclick="copyToClipboard('eth-address', this)" class="btn_box btn_alt cus-border border-color py-2 py-lg-3 px-4 w-100">
          Copy
        </button>
      </td>
    </tr>
    <tr>
      <td>
        <div class="d-flex align-items-center gap-2 gap-lg-3">
          <img src="assets/images/tron_med.png" class="box_8 rounded-circle" alt="TRX" />
          <span class="fw-medium">Tron (TRX)</span>
        </div>
      </td>
      <td>
        <div class="d-flex flex-column gap-1">
          <span class="fw-medium" id="trx-price">Tron Network</span>
        </div>
      </td>
      <td>
        <span class="fw-medium" id="trx-address"><?php echo $trx_address; ?></span>
      </td>
      <td>
        <button onclick="copyToClipboard('trx-address', this)" class="btn_box btn_alt cus-border border-color py-2 py-lg-3 px-4 w-100">
          Copy
        </button>
      </td>
    </tr>
    <tr>
      <td>
        <div class="d-flex align-items-center gap-2 gap-lg-3">
          <img src="assets/images/tether_mid.png" class="box_8 rounded-circle" alt="USDT" />
          <span class="fw-medium">Tether (USDT)</span>
        </div>
      </td>
      <td>
        <div class="d-flex flex-column gap-1">
          <span class="fw-medium" id="usdt-price">Ethereum</span>
        </div>
      </td>
      <td>
        <span class="fw-medium" id="usdt-address"><?php echo $usdt_address; ?></span>
      </td>
      <td>
        <button onclick="copyToClipboard('usdt-address', this)" class="btn_box btn_alt cus-border border-color py-2 py-lg-3 px-4 w-100">
          Copy
        </button>
      </td>
    </tr>
  </tbody>
</table>
          </div>
        </div>
      </div>
      <!-- Transaction history -->

      <div class="col-12">
        <div class="table-area overview_list n0-bg cus-rounded-1 p-4 p-lg-6 cus-border h-100">
          <div
            class="header-part d-flex flex-nowrap justify-content-between align-items-center gap-8 row-gap-3 pb-5 pb-xxl-6 mb-5 mb-xxl-6">
            <div class="d-flex align-items-center flex-wrap row-gap-3 gap-6 gap-xxl-8 w-100">
              <h4 class="fw-semibold">Transaction History</h4>
            </div>
          </div>
          <div class="table-main">
    <table>
      <tr>
        <th>Title</th>
        <th>Date</th>
        <th>Type of Transfer</th>
        <th>Status</th>
        <th>Transaction</th>
        <th>Value</th> <!-- New Value Column -->
      </tr>
      <?php
// API URL for CoinCap
$apiUrl = 'https://api.coincap.io/v2/assets';

// Fetch data from CoinCap API
$response = file_get_contents($apiUrl);
$data = json_decode($response, true);
$assetPrices = [];
foreach ($data['data'] as $asset) {
    $assetPrices[$asset['symbol']] = $asset['priceUsd'];
}

// Loop through the transactions and display them
foreach ($transactions as $transaction) {
    // Set the asset image and name based on the 'asset' field
    $asset_image = '';
    switch ($transaction['asset']) {
        case 'BTC':
            $asset_image = 'bitcoin.png';
            break;
        case 'ETH':
            $asset_image = 'ethereum.png';
            break;
        case 'TRX':
            $asset_image = 'tron_min.png';
            break;
        case 'USDT':
            $asset_image = 'tether.png';
            break;
        default:
            $asset_image = 'bitcoin.png'; // Default to BTC if asset type is unknown
            break;
    }

    // Set status colors based on the transaction status
    $status_class = '';
    $status_text = '';
    switch ($transaction['status']) {
        case 'Successful':
            $status_class = 'bg2-opty s1-color'; // Green for successful
            $status_text = 'Successful';
            break;
        case 'Pending':
            $status_class = 'bg4-opty s3-color'; // Yellow for pending
            $status_text = 'Pending';
            break;
        case 'Rejected':
            $status_class = 'bg3-opty s2-color'; // Red for rejected
            $status_text = 'Rejected';
            break;
        default:
            $status_class = 'bg2-opty s1-color'; // Default to successful
            $status_text = 'Unknown';
            break;
    }

    // Format the date
    $transaction_date = date('m/d/Y', strtotime($transaction['date_time']));

    // Calculate the USD value for the transaction
    $assetValueInUsd = $transaction['amount'] * $assetPrices[$transaction['asset']];
    $formattedUsdValue = number_format($assetValueInUsd, 2);

    // Determine if the transaction is a withdrawal or deposit for styling purposes
    $is_withdrawal = ($transaction['transaction_type'] == 'Withdrawal');
    
    // Adjust sign and color based on the type of transaction
    $value_class = $is_withdrawal ? 'text-danger' : 'text-success';  // Red for withdrawal, Green for deposit
    $sign = $is_withdrawal ? '-' : '';  // Add '-' for withdrawal transactions

    // Display each transaction in a table row
    echo "
    <tr>
        <td>
            <div class='d-flex align-items-center gap-3'>
                <img src='assets/images/$asset_image' alt='icon' />
                <span class='fw-medium'>" . $transaction['asset'] . "</span>
            </div>
        </td>
        <td>$transaction_date</td>
        <td>" . $transaction['transaction_type'] . "</td>
        <td>
            <span class='$status_class cus-border py-2 px-4 px-lg-5 text-center cus-rounded-2 w-100 cursor-pointer' onclick='openStatusModal(". $transaction['id'] .")'>$status_text</span>
        </td>
        <td>
            <div class='d-flex flex-column gap-1'>
                <span class='fw-medium $value_class'>$sign" . number_format($transaction['amount'], 8) . " " . $transaction['asset'] . "</span>
            </div>
        </td>
        <td>
            <div class='d-flex flex-column gap-1'>
                <span class='fw-medium'>$" . $formattedUsdValue . " USD</span> <!-- Value in USD -->
            </div>
        </td>
    </tr>";
}
?>

    </table>
  </div>
        </div>
      </div>
      
      <script>
        function copyToClipboard(elementId, buttonElement) {
          const address = document.getElementById(elementId).innerText;
          navigator.clipboard.writeText(address).then(() => {
            // Create a temporary message
            const message = document.createElement('span');
            message.innerText = 'Copied!';
            message.style.position = 'absolute';
            message.style.background = '#00c853';
            message.style.color = '#fff';
            message.style.padding = '5px 10px';
            message.style.borderRadius = '4px';
            message.style.fontSize = '12px';
            message.style.transform = 'translate(-50%, -50%)';
            message.style.top = '50%';
            message.style.left = '50%';
            buttonElement.style.position = 'relative';
            buttonElement.appendChild(message);
      
            // Automatically remove the message after 1 second
            setTimeout(() => {
              buttonElement.removeChild(message);
            }, 1000);
          }).catch(err => {
            console.error('Error copying to clipboard:', err);
          });
        }
      </script>
      
    </div>
  </div>
  </div>
  <!-- main end -->

    <!-- Modal -->
<div class="modal fade" id="statusModal" tabindex="-1" aria-labelledby="statusModalLabel" aria-hidden="true">
  <div class="modal-dialog">
    <div class="modal-content p-4">
      <div class="modal-header border-0">
        <h5 class="modal-title" id="statusModalLabel">Rejection Reason</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
      </div>
      <div class="modal-body mt-6" id="rejectonReasonModal">
      </div>
    </div>
  </div>
</div>


  <!-- Footer Area Start -->
  <footer class="footer">
    <div class="col-12">
      <div class="footer__copyright justify-content-center justify-content-sm-between gap-10 row-gap-2">
        <p class="copyright text-center">
          Copyright © <span id="copyYear"></span>. All Rights Reserved
        </p>
      </div>
    </div>
  </footer>
  <!-- Footer Area End -->

  <!-- ==== js dependencies start ==== -->
  <script src="assets/js/plugins/plugins.js"></script>
  <script src="assets/js/plugins/apexcharts.min.js"></script>
  <script src="https://cdn.quilljs.com/1.3.6/quill.js"></script>
  <script src="assets/js/plugins/custom_apexcharts.js"></script>
  <script src="assets/js/plugins/plugin-custom.js"></script>
  <script src="assets/js/main.js"></script>
  
  <script>
        var transactions = <?php echo json_encode($transactions); ?>;
        // Function to fetch and display the cryptocurrency data
        async function fetchCryptoData() {
            // URL to CoinCap API
            const url = 'https://api.coincap.io/v2/assets';
            
            try {
                // Fetch the cryptocurrency data from CoinCap API
                const response = await fetch(url);
                const data = await response.json();

                // Get relevant data for Bitcoin, Ethereum, Tron, and Tether
                const cryptos = data.data.filter(crypto => 
                    ['bitcoin', 'ethereum', 'tron', 'tether'].includes(crypto.id)
                );

                // Update the price and market cap for each cryptocurrency
                cryptos.forEach(crypto => {
                    const price = parseFloat(crypto.priceUsd).toFixed(2);
                    const marketCap = formatMarketCap(crypto.marketCapUsd);

                    // Display the price and market cap dynamically
                    document.getElementById(`${crypto.id}-price`).textContent = `$${price}`;
                    document.getElementById(`${crypto.id}-market-cap`).textContent = marketCap;
                });
            } catch (error) {
                console.error('Error fetching crypto data:', error);
            }
        }

        // Function to format market cap into a readable format (e.g., "1.2B" for 1,200,000,000)
        function formatMarketCap(value) {
            const marketCap = parseFloat(value);
            if (marketCap >= 1e12) {
                return (marketCap / 1e12).toFixed(1) + 'T'; // Trillions
            } else if (marketCap >= 1e9) {
                return (marketCap / 1e9).toFixed(1) + 'B'; // Billions
            } else if (marketCap >= 1e6) {
                return (marketCap / 1e6).toFixed(1) + 'M'; // Millions
            } else if (marketCap >= 1e3) {
                return (marketCap / 1e3).toFixed(1) + 'K'; // Thousands
            } else {
                return marketCap.toFixed(0); // Below thousands
            }
        }

        // Call the function when the page is loaded
        window.onload = fetchCryptoData;

        
        var myModal = new bootstrap.Modal(document.getElementById('statusModal'));

        function openModal() {
            myModal.show();
        }

        function closeModal() {
            myModal.hide();
        }

        function openStatusModal(transactionId) {
            var transactionSelected = transactions.find(transaction => transaction.id == transactionId);
            if(transactionSelected.status === 'Rejected') {
                $('#rejectonReasonModal').html(transactionSelected.rejection_reason ?? 'Rejection reason is not available.');
                openModal();
            }
        }


    </script>
</body>

</html>